@@ -313,14 +313,13 @@ finish_part (OstreeStaticDeltaBuilder *builder, GError **error)
 static OstreeStaticDeltaPartBuilder *
 allocate_part (OstreeStaticDeltaBuilder *builder, GError **error)
 {
-  OstreeStaticDeltaPartBuilder *part = g_new0 (OstreeStaticDeltaPartBuilder, 1);
-
   if (builder->parts->len > 0)
     {
       if (!finish_part (builder, error))
         return NULL;
     }
 
+  OstreeStaticDeltaPartBuilder *part = g_new0 (OstreeStaticDeltaPartBuilder, 1);
   part->objects = g_ptr_array_new_with_free_func ((GDestroyNotify)g_variant_unref);
   part->payload = g_string_new (NULL);
   part->operations = g_string_new (NULL);
@@ -1522,7 +1521,7 @@ ostree_repo_static_delta_generate (OstreeRepo                   *self,
             goto out;
         }
 
-      g_variant_builder_add_value (part_headers, g_variant_ref (part_builder->header));
+      g_variant_builder_add_value (part_headers, part_builder->header);
 
       total_compressed_size += part_builder->compressed_size;
       total_uncompressed_size += part_builder->uncompressed_size;
