@@ -28,10 +28,8 @@
 #include "ostree-core.h"
 #include "ostree-types.h"
 #include "ostree-async-progress.h"
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
 #include "ostree-ref.h"
 #include "ostree-repo-finder.h"
-#endif
 #include "ostree-sepolicy.h"
 #include "ostree-gpg-verify-result.h"
 
@@ -107,50 +105,6 @@ OstreeRepo *  ostree_repo_create_at (int             dfd,
                                      GCancellable   *cancellable,
                                      GError        **error);
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
-
-/**
- * OstreeRepoLockType:
- * @OSTREE_REPO_LOCK_SHARED: A shared lock
- * @OSTREE_REPO_LOCK_EXCLUSIVE: An exclusive lock
- *
- * The type of repository lock to acquire.
- *
- * Since: 2017.14
- */
-typedef enum {
-  OSTREE_REPO_LOCK_SHARED,
-  OSTREE_REPO_LOCK_EXCLUSIVE
-} OstreeRepoLockType;
-
-_OSTREE_PUBLIC
-gboolean      ostree_repo_lock_push (OstreeRepo          *self,
-                                     OstreeRepoLockType   lock_type,
-                                     GCancellable        *cancellable,
-                                     GError             **error);
-_OSTREE_PUBLIC
-gboolean      ostree_repo_lock_pop (OstreeRepo    *self,
-                                    GCancellable  *cancellable,
-                                    GError       **error);
-
-/**
- * OstreeRepoAutoLock: (skip)
- *
- * This is simply an alias to #OstreeRepo used for automatic lock cleanup.
- * See ostree_repo_auto_lock_push() for its intended usage.
- *
- * Since: 2017.14
- */
-typedef OstreeRepo OstreeRepoAutoLock;
-
-_OSTREE_PUBLIC
-OstreeRepoAutoLock * ostree_repo_auto_lock_push (OstreeRepo          *self,
-                                                 OstreeRepoLockType   lock_type,
-                                                 GCancellable        *cancellable,
-                                                 GError             **error);
-_OSTREE_PUBLIC
-void          ostree_repo_auto_lock_cleanup (OstreeRepoAutoLock *lock);
-
 _OSTREE_PUBLIC
 const gchar * ostree_repo_get_collection_id (OstreeRepo   *self);
 _OSTREE_PUBLIC
@@ -158,7 +112,8 @@ gboolean      ostree_repo_set_collection_id (OstreeRepo   *self,
                                              const gchar  *collection_id,
                                              GError      **error);
 
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
+_OSTREE_PUBLIC
+const gchar * const * ostree_repo_get_default_repo_finders (OstreeRepo   *self);
 
 _OSTREE_PUBLIC
 GFile *       ostree_repo_get_path (OstreeRepo  *self);
@@ -175,6 +130,10 @@ gboolean      ostree_repo_equal (OstreeRepo *a,
 _OSTREE_PUBLIC
 OstreeRepoMode ostree_repo_get_mode (OstreeRepo  *self);
 
+_OSTREE_PUBLIC
+gboolean       ostree_repo_get_min_free_space_bytes (OstreeRepo *self,
+                                                     guint64 *out_reserved_bytes,
+                                                     GError **error);
 _OSTREE_PUBLIC
 GKeyFile *    ostree_repo_get_config (OstreeRepo *self);
 
@@ -332,8 +291,9 @@ struct _OstreeRepoTransactionStats {
   guint content_objects_total;
   guint content_objects_written;
   guint64 content_bytes_written;
+  guint devino_cache_hits;
 
-  guint64 padding1;
+  guint   padding1;
   guint64 padding2;
   guint64 padding3;
   guint64 padding4;
@@ -381,15 +341,11 @@ void          ostree_repo_transaction_set_ref     (OstreeRepo *self,
                                                    const char *ref,
                                                    const char *checksum);
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
-
 _OSTREE_PUBLIC
 void          ostree_repo_transaction_set_collection_ref (OstreeRepo                *self,
                                                           const OstreeCollectionRef *ref,
                                                           const char                *checksum);
 
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
-
 _OSTREE_PUBLIC
 gboolean      ostree_repo_set_ref_immediate (OstreeRepo *self,
                                              const char *remote,
@@ -406,8 +362,6 @@ gboolean      ostree_repo_set_alias_ref_immediate (OstreeRepo *self,
                                                    GCancellable  *cancellable,
                                                    GError       **error);
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
-
 _OSTREE_PUBLIC
 gboolean      ostree_repo_set_collection_ref_immediate (OstreeRepo                 *self,
                                                         const OstreeCollectionRef  *ref,
@@ -415,8 +369,6 @@ gboolean      ostree_repo_set_collection_ref_immediate (OstreeRepo
                                                         GCancellable               *cancellable,
                                                         GError                    **error);
 
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
-
 _OSTREE_PUBLIC
 gboolean      ostree_repo_has_object (OstreeRepo           *self,
                                       OstreeObjectType      objtype,
@@ -521,7 +473,6 @@ gboolean      ostree_repo_resolve_rev_ext (OstreeRepo                    *self,
                                            char                         **out_rev,
                                            GError                       **error);
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
 _OSTREE_PUBLIC
 gboolean      ostree_repo_resolve_collection_ref (OstreeRepo                    *self,
                                                   const OstreeCollectionRef     *ref,
@@ -530,7 +481,6 @@ gboolean      ostree_repo_resolve_collection_ref (OstreeRepo
                                                   char                         **out_rev,
                                                   GCancellable                  *cancellable,
                                                   GError                       **error);
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
 
 _OSTREE_PUBLIC
 gboolean      ostree_repo_list_refs (OstreeRepo       *self,
@@ -566,14 +516,12 @@ gboolean ostree_repo_remote_list_refs (OstreeRepo       *self,
                                        GCancellable     *cancellable,
                                        GError          **error);
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
 _OSTREE_PUBLIC
 gboolean ostree_repo_remote_list_collection_refs (OstreeRepo    *self,
                                                   const char    *remote_name,
                                                   GHashTable   **out_all_refs,
                                                   GCancellable  *cancellable,
                                                   GError       **error);
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
 
 _OSTREE_PUBLIC
 gboolean      ostree_repo_load_variant (OstreeRepo  *self,
@@ -989,7 +937,8 @@ typedef struct {
   gboolean no_copy_fallback;
   gboolean force_copy; /* Since: 2017.6 */
   gboolean bareuseronly_dirs; /* Since: 2017.7 */
-  gboolean unused_bools[5];
+  gboolean force_copy_zerosized; /* Since: 2018.9 */
+  gboolean unused_bools[4];
   /* 4 byte hole on 64 bit */
 
   const char *subpath;
@@ -1112,6 +1061,12 @@ gboolean ostree_repo_static_delta_execute_offline (OstreeRepo
 _OSTREE_PUBLIC
 GHashTable *ostree_repo_traverse_new_reachable (void);
 
+_OSTREE_PUBLIC
+GHashTable *ostree_repo_traverse_new_parents (void);
+
+_OSTREE_PUBLIC
+char ** ostree_repo_traverse_parents_get_commits (GHashTable *parents, GVariant *object);
+
 _OSTREE_PUBLIC
 gboolean ostree_repo_traverse_commit (OstreeRepo         *repo,
                                       const char         *commit_checksum,
@@ -1127,6 +1082,14 @@ gboolean ostree_repo_traverse_commit_union (OstreeRepo         *repo,
                                             GHashTable         *inout_reachable,
                                             GCancellable       *cancellable,
                                             GError            **error);
+_OSTREE_PUBLIC
+gboolean ostree_repo_traverse_commit_union_with_parents (OstreeRepo         *repo,
+                                                         const char         *commit_checksum,
+                                                         int                 maxdepth,
+                                                         GHashTable         *inout_reachable,
+                                                         GHashTable         *inout_parents,
+                                                         GCancellable       *cancellable,
+                                                         GError            **error);
 
 struct _OstreeRepoCommitTraverseIter {
   gboolean initialized;
@@ -1230,6 +1193,14 @@ struct _OstreeRepoPruneOptions {
 
 typedef struct _OstreeRepoPruneOptions OstreeRepoPruneOptions;
 
+_OSTREE_PUBLIC
+gboolean
+ostree_repo_traverse_reachable_refs (OstreeRepo *self,
+                                     guint       depth,
+                                     GHashTable *reachable,
+                                     GCancellable *cancellable,
+                                     GError      **error);
+
 _OSTREE_PUBLIC
 gboolean ostree_repo_prune_from_reachable (OstreeRepo             *self,
                                            OstreeRepoPruneOptions *options,
@@ -1285,8 +1256,6 @@ gboolean ostree_repo_pull_with_options (OstreeRepo             *self,
                                         GCancellable           *cancellable,
                                         GError                **error);
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
-
 _OSTREE_PUBLIC
 void ostree_repo_find_remotes_async (OstreeRepo                         *self,
                                      const OstreeCollectionRef * const  *refs,
@@ -1328,8 +1297,6 @@ gboolean ostree_repo_list_collection_refs (OstreeRepo                 *self,
                                            GCancellable               *cancellable,
                                            GError                     **error);
 
-#endif /* OSTREE_ENABLE_EXPERIMENTAL_API */
-
 _OSTREE_PUBLIC
 void ostree_repo_pull_default_console_progress_changed (OstreeAsyncProgress *progress,
                                                         gpointer             user_data);
@@ -1414,8 +1381,6 @@ gboolean ostree_repo_regenerate_summary (OstreeRepo     *self,
                                          GCancellable   *cancellable,
                                          GError        **error);
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
-
 /**
  * OSTREE_REPO_METADATA_REF:
  *
@@ -1435,11 +1400,32 @@ gboolean ostree_repo_regenerate_summary (OstreeRepo     *self,
  * keys must be namespaced by product or developer. For example,
  * `exampleos.end-of-life`. The `ostree.` prefix is reserved.
  *
- * Since: 2017.8
+ * Since: 2018.6
  */
 #define OSTREE_REPO_METADATA_REF "ostree-metadata"
 
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
+/**
+ * OSTREE_META_KEY_DEPLOY_COLLECTION_ID:
+ *
+ * GVariant type `s`. This key can be used in the repo metadata which is stored
+ * in OSTREE_REPO_METADATA_REF as well as in the summary. The semantics of this
+ * are that the remote repository wants clients to update their remote config
+ * to add this collection ID (clients can't do P2P operations involving a
+ * remote without a collection ID configured on it, even if one is configured
+ * on the server side). Clients must never change or remove a collection ID
+ * already set in their remote config.
+ *
+ * Currently, OSTree does not implement changing a remote config based on this
+ * key, but it may do so in a later release, and until then clients such as
+ * Flatpak may implement it.
+ *
+ * This is a replacement for the similar metadata key implemented by flatpak,
+ * `xa.collection-id`, which is now deprecated as clients which supported it had
+ * bugs with their P2P implementations.
+ *
+ * Since: 2018.9
+ */
+#define OSTREE_META_KEY_DEPLOY_COLLECTION_ID "ostree.deploy-collection-id"
 
 G_END_DECLS
 
