@@ -34,6 +34,14 @@ else
 fi
 . ${test_srcdir}/libtest-core.sh
 
+save_core() {
+  if [ -e core ]; then
+    cp core "$test_srcdir/core"
+  fi
+}
+
+trap save_core EXIT;
+
 test_tmpdir=$(pwd)
 
 # Sanity check that we're in a tmpdir that has
@@ -491,7 +499,7 @@ os_repository_new_commit ()
 
     echo "content iteration ${content_iteration}" > usr/bin/content-iteration
 
-    version=$(date "+%Y%m%d.${content_iteration}")
+    export version=$(date "+%Y%m%d.${content_iteration}")
 
     ${CMD_PREFIX} ostree --repo=${test_tmpdir}/testos-repo commit  --add-metadata-string "version=${version}" -b $branch -s "Build"
     cd ${test_tmpdir}
@@ -640,3 +648,12 @@ assert_not_ref () {
         fatal "rev-parse $2 unexpectedly succeeded!"
     fi
 }
+
+assert_fail () {
+  set +e
+  $@
+  if [ $? = 0 ] ; then
+    echo 1>&2 "$@ did not fail"; exit 1
+  fi
+  set -euo pipefail
+}
