@@ -25,7 +25,7 @@ set -euo pipefail
 
 setup_fake_remote_repo1 "archive"
 
-echo '1..6'
+echo '1..7'
 
 cd ${test_tmpdir}
 mkdir repo
@@ -192,6 +192,11 @@ done
 ${CMD_PREFIX} ostree --repo=repo refs -A > refs.txt
 assert_file_has_content_literal refs.txt 'exampleos/x86_64/stable/server -> exampleos/x86_64/27/server'
 
+# Test that we don't delete a ref having aliases
+if ${CMD_PREFIX} ostree --repo=repo refs --delete exampleos/x86_64/27/server; then
+    assert_not_reached "refs --delete unexpectedly succeeded in deleting a ref containing alias!"
+fi
+
 ${CMD_PREFIX} ostree --repo=repo summary -u
 
 echo "ok ref symlink"
@@ -202,3 +207,9 @@ if ${CMD_PREFIX} ostree --repo=repo refs -A exampleos/x86_64/27/server --create=
 fi
 assert_file_has_content_literal err.txt 'Cannot create alias to remote ref'
 echo "ok ref no alias remote"
+
+if ${CMD_PREFIX} ostree --repo=repo refs -A --create foobar nonexistent 2>err.txt; then
+    fatal "Created alias to nonexistent ref?"
+fi
+assert_file_has_content_literal err.txt 'Cannot create alias to non-existent ref'
+echo "ok ref no broken alias"
